import classNames from 'classnames';
import { Bar, BarChart, CartesianGrid, ResponsiveContainer, Tooltip, XAxis, YAxis } from 'recharts';
import styles from './VerticalBarChart.component.module.scss';
import { getPrimaryBarValue, getSecondaryBarValue, PRIMARY_BAR_ANIMATION_PROPS, SECONDARY_BAR_ANIMATION_PROPS, useBarChart } from '../useBarChart.hook';
import ColoredBar from '../ColoredBar/ColoredBar.component';
import { ChartStyle } from '../../../types';
import TooltipCursor from '../TooltipCursor/TooltipCursor.component';
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
function VerticalBarChart({
  data,
  dataFeature,
  width,
  height,
  onBarClick,
  getTooltipContent,
  showXAxis
}) {
  const {
    focusedBarIndex,
    onClick,
    onMouseMove,
    onMouseOut,
    TooltipContent
  } = useBarChart(data, onBarClick, getTooltipContent);
  return /*#__PURE__*/_jsx(ResponsiveContainer, {
    height: height,
    width: width,
    children: /*#__PURE__*/_jsxs(BarChart, {
      data: data,
      className: classNames(styles['vertical-bar-chart']),
      onMouseMove: onMouseMove,
      layout: "horizontal",
      onClick: onClick,
      margin: {
        // Or labels will overflow
        bottom: showXAxis ? 40 : 10
      },
      onMouseLeave: onMouseOut,
      children: [/*#__PURE__*/_jsx(CartesianGrid, {
        strokeDasharray: "3 3",
        vertical: false
      }), /*#__PURE__*/_jsx(Bar, {
        dataKey: getPrimaryBarValue,
        stackId: "1",
        ...PRIMARY_BAR_ANIMATION_PROPS,
        shape: /*#__PURE__*/_jsx(ColoredBar, {
          chartStyle: ChartStyle.VALUE,
          barType: "primary",
          focusedBarIndex: focusedBarIndex
        })
      }), /*#__PURE__*/_jsx(Bar, {
        dataKey: getSecondaryBarValue,
        stackId: "1",
        ...SECONDARY_BAR_ANIMATION_PROPS,
        shape: /*#__PURE__*/_jsx(ColoredBar, {
          chartStyle: ChartStyle.VALUE,
          barType: "secondary",
          focusedBarIndex: focusedBarIndex
        })
      }), /*#__PURE__*/_jsx(Tooltip, {
        isAnimationActive: false,
        content: TooltipContent,
        cursor: /*#__PURE__*/_jsx(TooltipCursor, {
          dataFeature: dataFeature
        })
      }), showXAxis && /*#__PURE__*/_jsx(XAxis, {
        dataKey: "label",
        type: "category",
        interval: 0,
        angle: -45,
        textAnchor: "end"
      }), /*#__PURE__*/_jsx(YAxis, {
        dataKey: "value",
        orientation: "right",
        tickLine: false,
        type: "number",
        mirror: true,
        interval: 0
      })]
    })
  });
}
export default VerticalBarChart;
//# sourceMappingURL=VerticalBarChart.component.js.map