import { useEffect, useState } from 'react';
import VerticalBarChart from '../../BarChart/VerticalBarChart/VerticalBarChart.component';
import styles from './VerticalChartFilter.component.module.scss';
import RangeFilter from '../../RangeFilter/RangeFilter.component';
import KeyValueTooltip from '../../KeyValueTooltip/KeyValueTooltip.component';
import { getVerticalBarChartTooltip } from '../../BarChart/barChart.tooltip';
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
function VerticalChartFilter({
  activeRange,
  rangeLimits,
  data,
  barDataFeature,
  onBarClick,
  onRangeChange,
  rangeHandler,
  showXAxis
}) {
  const [sliderValue, setSliderValue] = useState(activeRange || rangeLimits);
  useEffect(() => {
    if (activeRange) {
      setSliderValue(activeRange);
    }
  }, [activeRange]);
  function isInActiveRange(entry) {
    // Check if bar is inside range, and handle bar min/max outside of rangelimits
    return sliderValue.min <= Math.max(rangeLimits.min, entry.key.min) && Math.min(rangeLimits.max, entry.key.max) <= sliderValue.max;
  }
  return /*#__PURE__*/_jsxs("div", {
    className: styles['vertical-chart-panel'],
    children: [/*#__PURE__*/_jsx("div", {
      className: styles['vertical-chart-panel__chart-container'],
      children: /*#__PURE__*/_jsx(VerticalBarChart, {
        showXAxis: showXAxis,
        data: data.map(entry => ({
          ...entry,
          value: entry.value,
          // undefined (no filter applied) !== 0 (not matching value)
          filteredValue: isInActiveRange(entry) ? entry.filteredValue : 0
        })),
        dataFeature: barDataFeature,
        onBarClick: onBarClick,
        getTooltipContent: entry => /*#__PURE__*/_jsx(KeyValueTooltip, {
          entries: getVerticalBarChartTooltip(entry)
        })
      })
    }), rangeLimits.min !== rangeLimits.max && /*#__PURE__*/_jsx("div", {
      className: styles['vertical-chart-panel__slider-container'],
      children: /*#__PURE__*/_jsx(RangeFilter, {
        range: sliderValue,
        limits: rangeLimits,
        onSliderChange: setSliderValue,
        onAfterChange: range => {
          onRangeChange(range);
        },
        ...rangeHandler
      })
    })]
  });
}
export default VerticalChartFilter;
//# sourceMappingURL=VerticalChartFilter.component.js.map