import { useMemo } from 'react';
import { useTranslation } from 'react-i18next';
import classNames from 'classnames';
import styles from './RangeFilter.component.module.scss';
import { I18N_DOMAIN_DATAVIZ } from '../../constants';
import { Slider } from "@talend/react-components";
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
function getMarks(ticks) {
  const marks = {};
  Object.entries(ticks).map(([value, label]) => [+value, label]).sort((a, b) => a[0] - b[0]).forEach(([value, label], i, arr) => {
    // Position: _ - - - _
    const position = {
      0: 'bottom-left',
      [arr.length - 1]: 'bottom-right'
    }[i] || 'top';
    marks[value] = /*#__PURE__*/_jsx("span", {
      className: classNames(styles['range-filter__slider-mark'], styles[`range-filter__slider-mark--${position}`]),
      children: label
    });
  });
  return marks;
}
function RangeFilter({
  id,
  range,
  limits,
  getMinValue = v => v,
  getMaxValue = v => v,
  getStep = () => 1,
  inputField: InputField,
  onSliderChange,
  onAfterChange,
  getTicks
}) {
  const {
    t
  } = useTranslation(I18N_DOMAIN_DATAVIZ);
  const marks = useMemo(() => getMarks(getTicks(limits)), [limits, getTicks]);

  // Prevent onAfterChange to be triggered twice
  let onAfterChangedCalled = false;
  return /*#__PURE__*/_jsxs("div", {
    className: styles['range-filter'],
    children: [/*#__PURE__*/_jsx("div", {
      className: styles['range-filter__slider'],
      children: /*#__PURE__*/_jsx(Slider, {
        step: getStep(limits),
        onChange: ([min, max]) => onSliderChange({
          min: getMinValue(min),
          max: getMaxValue(max)
        }),
        onAfterChange: ([min, max]) => {
          if (!onAfterChangedCalled) {
            onAfterChangedCalled = true;
            onAfterChange({
              min,
              max
            });
          }
        },
        min: limits.min,
        max: limits.max,
        value: [range.min, range.max],
        allowCross: false,
        hideTooltip: true,
        marks: marks
      })
    }), /*#__PURE__*/_jsxs("form", {
      className: styles['range-filter__form'],
      children: [/*#__PURE__*/_jsxs("div", {
        className: styles['range-filter__input-container'],
        children: [/*#__PURE__*/_jsx("label", {
          className: styles['range-filter__label'],
          htmlFor: `${id}-range-filter-min-input`,
          children: t('MIN', 'Min')
        }), /*#__PURE__*/_jsx(InputField, {
          id: `${id}-range-filter-min-input`,
          value: range.min,
          onChange: value => {
            onAfterChange({
              // Tricky one: we want the corrected value (i.e. day start) to stay between limits
              min: Math.min(Math.max(getMinValue(value), limits.min), range.max),
              max: range.max
            });
          }
        })]
      }), /*#__PURE__*/_jsxs("div", {
        className: styles['range-filter__input-container'],
        children: [/*#__PURE__*/_jsx("label", {
          className: styles['range-filter__label'],
          htmlFor: `${id}-range-filter-max-input`,
          children: t('MAX', 'Max')
        }), /*#__PURE__*/_jsx(InputField, {
          id: `${id}-range-filter-max-input`,
          value: range.max,
          onChange: value => onAfterChange({
            min: range.min,
            // Tricky one: we want the corrected value (i.e. day end) to stay between limits
            max: Math.max(range.min, Math.min(getMaxValue(value), limits.max))
          })
        })]
      })]
    })]
  });
}
export default RangeFilter;
//# sourceMappingURL=RangeFilter.component.js.map