import { endOfDay } from 'date-fns/endOfDay';
import { isValid } from 'date-fns/isValid';
import { parseISO } from 'date-fns/parseISO';
import { startOfDay } from 'date-fns/startOfDay';
import { formatDate } from '../../../../formatters/formatters';
import { formatTimeTicks } from '../slider-ticks.utils';
import useRangeInputField from '../useRangeInputField.hook';
import { InputDatePicker } from "@talend/react-components";
import { jsx as _jsx } from "react/jsx-runtime";
export function getMinValue(value) {
  return startOfDay(new Date(value)).getTime();
}
export function getMaxValue(value) {
  return endOfDay(new Date(value)).getTime();
}
function parser(input) {
  // Create date in locale time zone
  const date = parseISO(input);
  return isValid(date) ? date.getTime() : null;
}
export function DateInputField({
  id,
  value: rangeValue,
  onChange
}) {
  const {
    setInputValue,
    submit,
    ...props
  } = useRangeInputField(rangeValue, formatDate, parser, onChange);
  return /*#__PURE__*/_jsx(InputDatePicker, {
    id: id,
    onChange: (_, data) => {
      if (data.origin === 'PICKER') {
        submit(data.textInput);
      }
      setInputValue(data.textInput);
    },
    ...props
  });
}
export const DateRangeHandler = {
  inputField: DateInputField,
  getMinValue,
  getMaxValue,
  // slider should move day by day
  getStep: () => 24 * 3600 * 1000,
  getTicks: limits => formatTimeTicks(limits, formatDate)
};
//# sourceMappingURL=DateRangeHandler.js.map