import { useRef } from 'react';
import { endOfSecond } from 'date-fns/endOfSecond';
import { isValid } from 'date-fns/isValid';
import { parseISO } from 'date-fns/parseISO';
import { startOfSecond } from 'date-fns/startOfSecond';
import { formatDate, formatDateTime } from '../../../../formatters/formatters';
import { formatTimeTicks } from '../slider-ticks.utils';
import useRangeInputField from '../useRangeInputField.hook';
import styles from './DateTimeInputField.component.module.scss';
import { InputDateTimePicker } from "@talend/react-components";
import { jsx as _jsx } from "react/jsx-runtime";
function parser(input) {
  // Create date in locale time zone
  const date = parseISO(input);
  return isValid(date) ? date.getTime() : null;
}
export function DateTimeInputField({
  id,
  value: rangeValue,
  onChange
}) {
  const ref = useRef(null);
  const {
    setInputValue,
    submit,
    ...rest
  } = useRangeInputField(rangeValue, formatDateTime, parser, onChange);
  return /*#__PURE__*/_jsx("div", {
    ref: ref,
    className: styles['date-time-input-field'],
    children: /*#__PURE__*/_jsx(InputDateTimePicker, {
      id: id,
      useSeconds: true,
      onChange: (_, data) => {
        var _data$errors;
        if (!((_data$errors = data.errors) !== null && _data$errors !== void 0 && _data$errors.length)) {
          setInputValue(data.textInput);
        }
      },
      ...rest,
      onBlur: () => {
        var _ref$current;
        // Trigger onBlur when clicking outside the datepicker & inputs
        if (!((_ref$current = ref.current) !== null && _ref$current !== void 0 && _ref$current.contains(document.activeElement))) {
          rest.onBlur();
        }
      }
    })
  });
}
export const DateTimeRangeHandler = {
  inputField: DateTimeInputField,
  getMinValue: value => startOfSecond(value).getTime(),
  getMaxValue: value => endOfSecond(value).getTime(),
  getTicks: limits => formatTimeTicks(limits, formatDate)
};
//# sourceMappingURL=DateTimeRangeHandler.js.map