import classNames from 'classnames';
import { scaleLinear } from 'd3';
import { formatNumber, getFractionDigits } from '../../../../formatters/formatters';
import { formatD3Ticks } from '../slider-ticks.utils';
import useRangeInputField from '../useRangeInputField.hook';
import styles from './NumberInputField.component.module.scss';
import { jsx as _jsx } from "react/jsx-runtime";
const formatter = input => `${input}`;
const parser = input => +input;
function getPrecision(limits) {
  return Math.max(getFractionDigits(limits.min), getFractionDigits(limits.max));
}
function getStep(limits) {
  // rc-slider is really picky
  const precision = getPrecision(limits);
  return Number(`1e-${precision}`).toFixed(precision);
}
function getTicks(limits) {
  const precision = getPrecision(limits);
  const maxDigits = Math.max(formatNumber(limits.min, precision).length, formatNumber(limits.max, precision).length);

  // Use number of chars in formatted number to guess how many ticks we can show
  const tickCount = maxDigits < 11 ? 3 : 1;
  return formatD3Ticks(limits, scaleLinear().domain([limits.min, limits.max]).ticks(tickCount), v => formatNumber(v, +getPrecision(limits)));
}
export function NumberInputField({
  id,
  value: rangeValue,
  onChange
}) {
  const {
    setInputValue,
    submit,
    ...props
  } = useRangeInputField(rangeValue, formatter, parser, onChange);
  return /*#__PURE__*/_jsx("input", {
    id: id,
    className: classNames(styles['number-input-field']),
    type: "number",
    step: "any",
    onChange: event => setInputValue(event.target.value),
    ...props
  });
}
export const NumberRangeHandler = {
  inputField: NumberInputField,
  getStep,
  getTicks
};
//# sourceMappingURL=NumberRangeHandler.js.map