import { scaleTime } from 'd3';
import { isValid } from 'date-fns/isValid';
import { formatD3Ticks, formatTimeTicks } from '../slider-ticks.utils';
import useRangeInputField from '../useRangeInputField.hook';
import { InputTimePicker } from "@talend/react-components";
import { jsx as _jsx } from "react/jsx-runtime";
function parser(input) {
  const date = new Date(`1970-01-01T${input}Z`);
  return isValid(date) ? Math.floor(date.getTime() / 1000) : null;
}
function formatter(value) {
  return new Date(value * 1000).toISOString().substr(11, 8);
}
export function getTicks(limits) {
  return formatD3Ticks(limits, scaleTime().domain([limits.min, limits.max]).ticks(3).map(v => v.getTime()), formatter);
}
export function TimeInputField({
  id,
  value: rangeValue,
  onChange
}) {
  const {
    setInputValue,
    submit,
    ...rest
  } = useRangeInputField(rangeValue, formatter, parser, onChange);
  return /*#__PURE__*/_jsx(InputTimePicker, {
    id: id,
    useSeconds: true,
    onChange: (_, data) => {
      if (data.origin === 'PICKER') {
        submit(data.textInput);
      }
      setInputValue(data.textInput);
    },
    ...rest
  });
}
export const TimeRangeHandler = {
  inputField: TimeInputField,
  getMinValue: Math.floor,
  getMaxValue: Math.floor,
  getTicks: limits => formatTimeTicks(limits, formatter)
};
//# sourceMappingURL=TimeRangeHandler.js.map