import { scaleTime } from 'd3';
export function formatD3Ticks(limits, scale, formatter) {
  // D3 returns an array "of approximately count + 1 uniformly-spaced, nicely-rounded values between start and stop"
  // It's nice, but we want to make sure we'll always show min and max values
  const ticks = {};
  // Add min/max and remove duplicates, then create a map [value, label to display]
  [limits.min, limits.max, ...scale].forEach((value, index) => {
    const label = formatter(value);
    // We want min and max even if they have the same label
    if (index < 2 || !Object.values(ticks).includes(label)) {
      ticks[value] = label;
    }
  });
  return ticks;
}
export function formatTimeTicks(limits, formatter) {
  return formatD3Ticks(limits, scaleTime().domain([limits.min, limits.max]).ticks(3).map(v => v.getTime()), formatter);
}
//# sourceMappingURL=slider-ticks.utils.js.map