import { useCallback, useEffect, useState } from 'react';
function useRangeInputField(rangeValue, formatter, parser, onChange) {
  const [inputValue, setInputValue] = useState('');
  const resetValue = useCallback(() => {
    setInputValue(formatter(rangeValue));
  }, [formatter, rangeValue]);
  function submit(stringValue) {
    const parsed = parser(stringValue);
    if (parsed !== null) {
      if (parsed !== rangeValue) {
        onChange(parsed);
      }
    } else {
      resetValue();
    }
  }
  useEffect(() => {
    resetValue();
  }, [resetValue]);
  return {
    value: inputValue,
    setInputValue,
    onKeyDown: event => {
      if (event.key === 'Enter') {
        submit(inputValue);
      } else if (event.key === 'Escape') {
        resetValue();
      }
    },
    onBlur: () => submit(inputValue),
    submit
  };
}
export default useRangeInputField;
//# sourceMappingURL=useRangeInputField.hook.js.map