"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.SECONDARY_BAR_ANIMATION_PROPS = exports.PRIMARY_BAR_ANIMATION_PROPS = void 0;
exports.getPrimaryBarValue = getPrimaryBarValue;
exports.getSecondaryBarValue = getSecondaryBarValue;
exports.useBarChart = useBarChart;
var _react = require("react");
const ANIMATION_DURATION = 80;
const PRIMARY_BAR_ANIMATION_PROPS = exports.PRIMARY_BAR_ANIMATION_PROPS = {
  animationBegin: 0,
  animationDuration: ANIMATION_DURATION,
  animationEasing: 'linear'
};
const SECONDARY_BAR_ANIMATION_PROPS = exports.SECONDARY_BAR_ANIMATION_PROPS = {
  animationBegin: ANIMATION_DURATION,
  animationDuration: ANIMATION_DURATION,
  animationEasing: 'linear'
};

/**
 * Primary bar shows
 * - filtered data if any
 * - unfiltered data otherwise
 */
function getPrimaryBarValue(entry) {
  return entry.filteredValue != null ? entry.filteredValue : entry.value;
}

/**
 * Secondary bar shows data not matching filter (if any)
 */
function getSecondaryBarValue(entry) {
  let value = null;
  if (entry.filteredValue != null && entry.value != null) {
    value = entry.value - entry.filteredValue;
  }
  return value;
}
function useBarChart(data, onBarClick, getTooltipContent) {
  const [focusedBarIndex, setFocusedBarIndex] = (0, _react.useState)(null);
  const entry = focusedBarIndex != null ? data[focusedBarIndex] : null;
  return {
    focusedBarIndex,
    onMouseOut: () => setFocusedBarIndex(null),
    onMouseMove: state => {
      setFocusedBarIndex(state.isTooltipActive ? state.activeTooltipIndex : null);
    },
    onClick: (_, event) => {
      if (entry) {
        onBarClick(event, entry);
      }
    },
    TooltipContent: () => entry ? getTooltipContent(entry) : null
  };
}
//# sourceMappingURL=useBarChart.hook.js.map