"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = require("react");
var _reactI18next = require("react-i18next");
var _classnames = _interopRequireDefault(require("classnames"));
var _RangeFilterComponentModule = _interopRequireDefault(require("./RangeFilter.component.module.scss"));
var _constants = require("../../constants");
var _reactComponents = require("@talend/react-components");
var _jsxRuntime = require("react/jsx-runtime");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
function getMarks(ticks) {
  const marks = {};
  Object.entries(ticks).map(([value, label]) => [+value, label]).sort((a, b) => a[0] - b[0]).forEach(([value, label], i, arr) => {
    // Position: _ - - - _
    const position = {
      0: 'bottom-left',
      [arr.length - 1]: 'bottom-right'
    }[i] || 'top';
    marks[value] = /*#__PURE__*/(0, _jsxRuntime.jsx)("span", {
      className: (0, _classnames.default)(_RangeFilterComponentModule.default['range-filter__slider-mark'], _RangeFilterComponentModule.default[`range-filter__slider-mark--${position}`]),
      children: label
    });
  });
  return marks;
}
function RangeFilter({
  id,
  range,
  limits,
  getMinValue = v => v,
  getMaxValue = v => v,
  getStep = () => 1,
  inputField: InputField,
  onSliderChange,
  onAfterChange,
  getTicks
}) {
  const {
    t
  } = (0, _reactI18next.useTranslation)(_constants.I18N_DOMAIN_DATAVIZ);
  const marks = (0, _react.useMemo)(() => getMarks(getTicks(limits)), [limits, getTicks]);

  // Prevent onAfterChange to be triggered twice
  let onAfterChangedCalled = false;
  return /*#__PURE__*/(0, _jsxRuntime.jsxs)("div", {
    className: _RangeFilterComponentModule.default['range-filter'],
    children: [/*#__PURE__*/(0, _jsxRuntime.jsx)("div", {
      className: _RangeFilterComponentModule.default['range-filter__slider'],
      children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactComponents.Slider, {
        step: getStep(limits),
        onChange: ([min, max]) => onSliderChange({
          min: getMinValue(min),
          max: getMaxValue(max)
        }),
        onAfterChange: ([min, max]) => {
          if (!onAfterChangedCalled) {
            onAfterChangedCalled = true;
            onAfterChange({
              min,
              max
            });
          }
        },
        min: limits.min,
        max: limits.max,
        value: [range.min, range.max],
        allowCross: false,
        hideTooltip: true,
        marks: marks
      })
    }), /*#__PURE__*/(0, _jsxRuntime.jsxs)("form", {
      className: _RangeFilterComponentModule.default['range-filter__form'],
      children: [/*#__PURE__*/(0, _jsxRuntime.jsxs)("div", {
        className: _RangeFilterComponentModule.default['range-filter__input-container'],
        children: [/*#__PURE__*/(0, _jsxRuntime.jsx)("label", {
          className: _RangeFilterComponentModule.default['range-filter__label'],
          htmlFor: `${id}-range-filter-min-input`,
          children: t('MIN', 'Min')
        }), /*#__PURE__*/(0, _jsxRuntime.jsx)(InputField, {
          id: `${id}-range-filter-min-input`,
          value: range.min,
          onChange: value => {
            onAfterChange({
              // Tricky one: we want the corrected value (i.e. day start) to stay between limits
              min: Math.min(Math.max(getMinValue(value), limits.min), range.max),
              max: range.max
            });
          }
        })]
      }), /*#__PURE__*/(0, _jsxRuntime.jsxs)("div", {
        className: _RangeFilterComponentModule.default['range-filter__input-container'],
        children: [/*#__PURE__*/(0, _jsxRuntime.jsx)("label", {
          className: _RangeFilterComponentModule.default['range-filter__label'],
          htmlFor: `${id}-range-filter-max-input`,
          children: t('MAX', 'Max')
        }), /*#__PURE__*/(0, _jsxRuntime.jsx)(InputField, {
          id: `${id}-range-filter-max-input`,
          value: range.max,
          onChange: value => onAfterChange({
            min: range.min,
            // Tricky one: we want the corrected value (i.e. day end) to stay between limits
            max: Math.max(range.min, Math.min(getMaxValue(value), limits.max))
          })
        })]
      })]
    })]
  });
}
var _default = exports.default = RangeFilter;
//# sourceMappingURL=RangeFilter.component.js.map