"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.DateInputField = DateInputField;
exports.DateRangeHandler = void 0;
exports.getMaxValue = getMaxValue;
exports.getMinValue = getMinValue;
var _endOfDay = require("date-fns/endOfDay");
var _isValid = require("date-fns/isValid");
var _parseISO = require("date-fns/parseISO");
var _startOfDay = require("date-fns/startOfDay");
var _formatters = require("../../../../formatters/formatters");
var _sliderTicks = require("../slider-ticks.utils");
var _useRangeInputField = _interopRequireDefault(require("../useRangeInputField.hook"));
var _reactComponents = require("@talend/react-components");
var _jsxRuntime = require("react/jsx-runtime");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
function getMinValue(value) {
  return (0, _startOfDay.startOfDay)(new Date(value)).getTime();
}
function getMaxValue(value) {
  return (0, _endOfDay.endOfDay)(new Date(value)).getTime();
}
function parser(input) {
  // Create date in locale time zone
  const date = (0, _parseISO.parseISO)(input);
  return (0, _isValid.isValid)(date) ? date.getTime() : null;
}
function DateInputField({
  id,
  value: rangeValue,
  onChange
}) {
  const {
    setInputValue,
    submit,
    ...props
  } = (0, _useRangeInputField.default)(rangeValue, _formatters.formatDate, parser, onChange);
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactComponents.InputDatePicker, {
    id: id,
    onChange: (_, data) => {
      if (data.origin === 'PICKER') {
        submit(data.textInput);
      }
      setInputValue(data.textInput);
    },
    ...props
  });
}
const DateRangeHandler = exports.DateRangeHandler = {
  inputField: DateInputField,
  getMinValue,
  getMaxValue,
  // slider should move day by day
  getStep: () => 24 * 3600 * 1000,
  getTicks: limits => (0, _sliderTicks.formatTimeTicks)(limits, _formatters.formatDate)
};
//# sourceMappingURL=DateRangeHandler.js.map