"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.DateTimeInputField = DateTimeInputField;
exports.DateTimeRangeHandler = void 0;
var _react = require("react");
var _endOfSecond = require("date-fns/endOfSecond");
var _isValid = require("date-fns/isValid");
var _parseISO = require("date-fns/parseISO");
var _startOfSecond = require("date-fns/startOfSecond");
var _formatters = require("../../../../formatters/formatters");
var _sliderTicks = require("../slider-ticks.utils");
var _useRangeInputField = _interopRequireDefault(require("../useRangeInputField.hook"));
var _DateTimeInputFieldComponentModule = _interopRequireDefault(require("./DateTimeInputField.component.module.scss"));
var _reactComponents = require("@talend/react-components");
var _jsxRuntime = require("react/jsx-runtime");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
function parser(input) {
  // Create date in locale time zone
  const date = (0, _parseISO.parseISO)(input);
  return (0, _isValid.isValid)(date) ? date.getTime() : null;
}
function DateTimeInputField({
  id,
  value: rangeValue,
  onChange
}) {
  const ref = (0, _react.useRef)(null);
  const {
    setInputValue,
    submit,
    ...rest
  } = (0, _useRangeInputField.default)(rangeValue, _formatters.formatDateTime, parser, onChange);
  return /*#__PURE__*/(0, _jsxRuntime.jsx)("div", {
    ref: ref,
    className: _DateTimeInputFieldComponentModule.default['date-time-input-field'],
    children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactComponents.InputDateTimePicker, {
      id: id,
      useSeconds: true,
      onChange: (_, data) => {
        var _data$errors;
        if (!((_data$errors = data.errors) !== null && _data$errors !== void 0 && _data$errors.length)) {
          setInputValue(data.textInput);
        }
      },
      ...rest,
      onBlur: () => {
        var _ref$current;
        // Trigger onBlur when clicking outside the datepicker & inputs
        if (!((_ref$current = ref.current) !== null && _ref$current !== void 0 && _ref$current.contains(document.activeElement))) {
          rest.onBlur();
        }
      }
    })
  });
}
const DateTimeRangeHandler = exports.DateTimeRangeHandler = {
  inputField: DateTimeInputField,
  getMinValue: value => (0, _startOfSecond.startOfSecond)(value).getTime(),
  getMaxValue: value => (0, _endOfSecond.endOfSecond)(value).getTime(),
  getTicks: limits => (0, _sliderTicks.formatTimeTicks)(limits, _formatters.formatDate)
};
//# sourceMappingURL=DateTimeRangeHandler.js.map