"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.NumberInputField = NumberInputField;
exports.NumberRangeHandler = void 0;
var _classnames = _interopRequireDefault(require("classnames"));
var _d = require("d3");
var _formatters = require("../../../../formatters/formatters");
var _sliderTicks = require("../slider-ticks.utils");
var _useRangeInputField = _interopRequireDefault(require("../useRangeInputField.hook"));
var _NumberInputFieldComponentModule = _interopRequireDefault(require("./NumberInputField.component.module.scss"));
var _jsxRuntime = require("react/jsx-runtime");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
const formatter = input => `${input}`;
const parser = input => +input;
function getPrecision(limits) {
  return Math.max((0, _formatters.getFractionDigits)(limits.min), (0, _formatters.getFractionDigits)(limits.max));
}
function getStep(limits) {
  // rc-slider is really picky
  const precision = getPrecision(limits);
  return Number(`1e-${precision}`).toFixed(precision);
}
function getTicks(limits) {
  const precision = getPrecision(limits);
  const maxDigits = Math.max((0, _formatters.formatNumber)(limits.min, precision).length, (0, _formatters.formatNumber)(limits.max, precision).length);

  // Use number of chars in formatted number to guess how many ticks we can show
  const tickCount = maxDigits < 11 ? 3 : 1;
  return (0, _sliderTicks.formatD3Ticks)(limits, (0, _d.scaleLinear)().domain([limits.min, limits.max]).ticks(tickCount), v => (0, _formatters.formatNumber)(v, +getPrecision(limits)));
}
function NumberInputField({
  id,
  value: rangeValue,
  onChange
}) {
  const {
    setInputValue,
    submit,
    ...props
  } = (0, _useRangeInputField.default)(rangeValue, formatter, parser, onChange);
  return /*#__PURE__*/(0, _jsxRuntime.jsx)("input", {
    id: id,
    className: (0, _classnames.default)(_NumberInputFieldComponentModule.default['number-input-field']),
    type: "number",
    step: "any",
    onChange: event => setInputValue(event.target.value),
    ...props
  });
}
const NumberRangeHandler = exports.NumberRangeHandler = {
  inputField: NumberInputField,
  getStep,
  getTicks
};
//# sourceMappingURL=NumberRangeHandler.js.map