"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.TimeInputField = TimeInputField;
exports.TimeRangeHandler = void 0;
exports.getTicks = getTicks;
var _d = require("d3");
var _isValid = require("date-fns/isValid");
var _sliderTicks = require("../slider-ticks.utils");
var _useRangeInputField = _interopRequireDefault(require("../useRangeInputField.hook"));
var _reactComponents = require("@talend/react-components");
var _jsxRuntime = require("react/jsx-runtime");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
function parser(input) {
  const date = new Date(`1970-01-01T${input}Z`);
  return (0, _isValid.isValid)(date) ? Math.floor(date.getTime() / 1000) : null;
}
function formatter(value) {
  return new Date(value * 1000).toISOString().substr(11, 8);
}
function getTicks(limits) {
  return (0, _sliderTicks.formatD3Ticks)(limits, (0, _d.scaleTime)().domain([limits.min, limits.max]).ticks(3).map(v => v.getTime()), formatter);
}
function TimeInputField({
  id,
  value: rangeValue,
  onChange
}) {
  const {
    setInputValue,
    submit,
    ...rest
  } = (0, _useRangeInputField.default)(rangeValue, formatter, parser, onChange);
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactComponents.InputTimePicker, {
    id: id,
    useSeconds: true,
    onChange: (_, data) => {
      if (data.origin === 'PICKER') {
        submit(data.textInput);
      }
      setInputValue(data.textInput);
    },
    ...rest
  });
}
const TimeRangeHandler = exports.TimeRangeHandler = {
  inputField: TimeInputField,
  getMinValue: Math.floor,
  getMaxValue: Math.floor,
  getTicks: limits => (0, _sliderTicks.formatTimeTicks)(limits, formatter)
};
//# sourceMappingURL=TimeRangeHandler.js.map